using System;
using System.Collections;
using Server.Gumps;
using Server.Network;
using Server.Items;
using Server.Targeting;


namespace Server.Items
{
	public class SpellbookCertificate : Item
	{
		public ArrayList SpellContents;
		private bool InfoStored = false;
		
		[Constructable]
		public SpellbookCertificate() : base( 0x14F0 )
		{
			base.Name = " a Spellbook Certificate";
			base.Weight = 1.0;
			base.Hue = 0x851;
			
			SpellContents = new ArrayList();
		}
		
		public override void OnDoubleClick( Mobile from )
		{
			if ( !IsChildOf( from.Backpack ) ) // Make sure its in their pack
				from.SendLocalizedMessage( 1042001 ); // That must be in your pack for you to use it.
			
			else
				from.SendGump( new SpellbookCertificateGump( from, this ) );
		}
		
		public SpellbookCertificate( Serial serial ) : base( serial )
		{
		}
		
		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 ); // version
			
			writer.Write( (bool)InfoStored );
			
			writer.Write( (int)SpellContents.Count );
			for( int i = 0; i < SpellContents.Count; i++ )
				writer.Write( (int)SpellContents[i] );
		}
		
		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
			
			InfoStored = reader.ReadBool();
			
			SpellContents = new ArrayList();
			
			int count = reader.ReadInt();
			
			for( int i = 0; i < count; i++ )
				SpellContents.Add( reader.ReadInt() );
		}
	}
	
	
	public class SpellbookCertificateGump : Gump
	{
		private Mobile m_Mobile;
		private SpellbookCertificate m_cert;
		
		string c1 = "Spellbook";
		string c2 = "Cleric Spellbook";
		string c3 = "Druid Spellbook";
		string c4 = "Song Book";
		string c5 = "Ranger Spellbook";
		string c6 = "Rogue Spellbook";
		string c7 = "Book Of Chivalry";
		string c8 = "Necromancer Spellbook";
		string c9 = "Book Of Ninjitsu";
		string c10 = "Book Of Bushido";
		string c11 = "Arcanist Spellbook";
		
		public SpellbookCertificateGump( Mobile from, SpellbookCertificate sbc ) : base( 0, 0 )
		{
			m_cert = sbc;
			from.CloseGump( typeof ( SpellbookCertificateGump ) );
			this.Closable=true;
			this.Disposable=false;
			this.Dragable=true;
			this.Resizable=false;
			
			//<<Page One>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
			AddPage( 1 );
			AddWindow();
			//this.AddPage(0);
			
			//--<<Title>>----------------------------------------------------------------------<>
			this.AddLabel(177, 145, 1485, @"Choose Your Spellbook");
			//--<<Title>>----------------------------------------------------------------------<>
			
			//--<<Spellbook Menu>>-<<Page 1>>-------------------------------------------------<Start>
			this.AddLabel(180, 175, 0, c1);
			this.AddButton(145, 170, 2152, 2154, 1/*Button Number*/, GumpButtonType.Reply, 0);
			
			this.AddLabel(180, 205, 0, c2);
			this.AddButton(145, 200, 2152, 2154, 2/*Button Number*/, GumpButtonType.Reply, 0);
			
			this.AddLabel(180, 235, 0, c3);
			this.AddButton(145, 230, 2152, 2154, 3/*Button Number*/, GumpButtonType.Reply, 0);
			
			this.AddLabel(180, 264, 0, c4);
			this.AddButton(145, 260, 2152, 2154, 4/*Button Number*/, GumpButtonType.Reply, 0);
			
			this.AddLabel(180, 295, 0, c5);
			this.AddButton(145, 290, 2152, 2154, 5/*Button Number*/, GumpButtonType.Reply, 0);
			
			this.AddLabel(180, 325, 0, c6);
			this.AddButton(145, 320, 2152, 2154, 6/*Button Number*/, GumpButtonType.Reply, 0);
			
			this.AddLabel(180, 355, 0, c7);
			this.AddButton(145, 350, 2152, 2154, 7/*Button Number*/, GumpButtonType.Reply, 0);
			
			this.AddLabel(180, 385, 0, c8);
			this.AddButton(145, 380, 2152, 2154, 8/*Button Number*/, GumpButtonType.Reply, 0);
			//--<<Spellbook Menu>>-<<Page 1>>---------------------------------------------------<End>
			
			//--<<Turn Page Buttons>>-<<Page 1>>------------------------------------------<Start>
			//Turn pages with these buttons:
			this.AddButton(290, 415, 59, 2154, 0/*Page Number*/,   GumpButtonType.Page, 2);
			//this.AddButton(145, 415, 57, 2154, 0/*Page Number*/,  GumpButtonType.Reply, 0);
			//--<<Turn Page Buttons>>-<<Page 1>>--------------------------------------------<End>
			
			//<<Page One>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
			
			
			//<<Page Two>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
			AddPage( 2 );
			AddWindow();
			//this.AddPage(0);
			
			//--<<Title>>----------------------------------------------------------------------<>
			this.AddLabel(177, 145, 1485, @"Choose Your Spellbook");
			//--<<Title>>----------------------------------------------------------------------<>
			
			//--<<Spellbook Menu>>-<<Page 2>>-------------------------------------------------<Start>
			this.AddLabel(180, 175, 0, c9);
			this.AddButton(145, 170, 2152, 2154, 9/*Button Number*/, GumpButtonType.Reply, 0);
			
			this.AddLabel(180, 205, 0, c10);
			this.AddButton(145, 200, 2152, 2154, 10/*Button Number*/, GumpButtonType.Reply, 0);
			
			this.AddLabel(180, 235, 0, c11);
			this.AddButton(145, 230, 2152, 2154, 11/*Button Number*/, GumpButtonType.Reply, 0);
			//--<<Spellbook Menu>>-<<Page 2>>---------------------------------------------------<End>
			
			//--<<Turn Page Buttons>>-<<Page 2>>------------------------------------------<Start>
			//Turn pages with these buttons:
			//this.AddButton(290, 415, 59, 2154, 0/*Page Number*/,   GumpButtonType.Page, 3);
			this.AddButton(145, 415, 57, 2154, 0/*Page Number*/,  GumpButtonType.Page, 1);
			//--<<Turn Page Buttons>>-<<Page 2>>--------------------------------------------<End>
			//<<Page Two>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
		}
		
		private void AddWindow()
		{
			this.AddBackground(124, 128, 219, 318, 9200);
			this.AddImage(132, 138, 48);
			this.AddImage(331, 406, 10464);
			this.AddImage(141, 147, 1124);
			this.AddImage(103, 65, 10463);
			this.AddImage(233, 65, 10463);
			this.AddImage(103, 136, 10464);
			this.AddImage(103, 190, 10464);
			this.AddImage(103, 244, 10464);
			this.AddImage(103, 298, 10464);
			this.AddImage(103, 352, 10464);
			this.AddImage(103, 406, 10464);
			this.AddImage(103, 440, 10463);
			this.AddImage(331, 136, 10464);
			this.AddImage(233, 440, 10463);
			this.AddImage(331, 190, 10464);
			this.AddImage(331, 244, 10464);
			this.AddImage(331, 298, 10464);
			this.AddImage(331, 352, 10464);
			this.AddImage(199, 57, 9804);
			this.AddImage(198, 425, 9000);
			this.AddImage(295, 447, 5569);
			this.AddImage(109, 447, 5567);
			this.AddImage(295, 70, 5553);
			this.AddImage(109, 70, 5549);
			this.AddImage(201, 447, 112);
		}
		
		public override void OnResponse( NetState state, RelayInfo info )
		{
			Mobile from = state.Mobile;
			Container pack = from.Backpack;
			BankBox Banker = from.BankBox;
			
			if ( from == null || pack == null || m_cert == null )
				return;
			
			if ( m_cert.Deleted )
				return;
			
			if ( !m_cert.IsChildOf( from.Backpack ) )
			{
				from.SendLocalizedMessage( 1042010 ); //You must have the object in your backpack to use it.
				return;
			}
			
			switch ( info.ButtonID )
			{
				case 0: //Close Gump
					{
						from.CloseGump( typeof ( SpellbookCertificateGump ) );
						break;
					}
					
				case 1: //Spellbook
					{
						from.AddToBackpack( new Spellbook() );
						from.CloseGump( typeof ( SpellbookCertificateGump ) );
						m_cert.Delete();
						break;
					}
				case 2: //Cleric Spellbook
					{
						from.AddToBackpack( new ClericSpellbook() );
						from.CloseGump( typeof ( SpellbookCertificateGump ) );
						m_cert.Delete();
						break;
					}
				case 3: //Druid Spellbook
					{
						from.AddToBackpack( new DruidSpellbook() );
						from.CloseGump( typeof ( SpellbookCertificateGump ) );
						m_cert.Delete();
						break;
					}
				case 4: //Bard Spellbook
					{
						from.AddToBackpack( new SongBook() );
						from.CloseGump( typeof ( SpellbookCertificateGump ) );
						m_cert.Delete();
						break;
					}
				case 5: //Ranger Spellbook
					{
						from.AddToBackpack( new RangerSpellbook() );
						from.CloseGump( typeof ( SpellbookCertificateGump ) );
						m_cert.Delete();
						break;
					}
				case 6: //Rogue Spellbook
					{
						from.AddToBackpack( new RogueSpellbook() );
						from.CloseGump( typeof ( SpellbookCertificateGump ) );
						m_cert.Delete();
						break;
					}
				case 7: //Pally Spellbook
					{
						from.AddToBackpack( new BookOfChivalry() );
						from.CloseGump( typeof ( SpellbookCertificateGump ) );
						m_cert.Delete();
						break;
					}
				case 8: //Necromancer Spellbook
					{
						from.AddToBackpack( new NecromancerSpellbook() );
						from.CloseGump( typeof ( SpellbookCertificateGump ) );
						m_cert.Delete();
						break;
					}
				case 9: //Ninja Spellbook
					{
						from.AddToBackpack( new BookOfNinjitsu() );
						from.CloseGump( typeof ( SpellbookCertificateGump ) );
						m_cert.Delete();
						break;
					}
				case 10: //Samurai Spellbook
					{
						from.AddToBackpack( new BookOfBushido() );
						from.CloseGump( typeof ( SpellbookCertificateGump ) );
						m_cert.Delete();
						break;
					}
				case 11: //Arcanist Spellbook [Spellweaving]
					{
						from.AddToBackpack( new SpellweavingBook() );
						from.CloseGump( typeof ( SpellbookCertificateGump ) );
						m_cert.Delete();
						break;
					}
			}
		}
	}
}

